@@ -20,13 +20,13 @@ from typing import (
     Union,
 )
 
-import pythonflow as pf
 import tenacity
 from gql import (
     Client,
     gql,
 )
 from qctrlcommons.exceptions import QctrlException
+from qctrlcommons.graph import Graph
 from requests.exceptions import (
     BaseHTTPError,
     RequestException,
@@ -163,11 +163,11 @@ class Qctrl:
         ) = build_namespaces(self)
 
     @staticmethod
-    def create_graph():
+    def create_graph(name: str = None) -> Graph:
         """
-        Creates a graph object.
+        Create a `Graph` object.
         """
-        return pf.Graph()
+        return Graph(name=name)
 
     def activity_monitor(
         self,
